==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/LoadBalancerListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface LoadBalancerListenerOverrideFluent<A extends LoadBalancerListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public LoadBalancerListenerBootstrapOverride getBootstrap();
    public LoadBalancerListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(LoadBalancerListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(LoadBalancerListenerBootstrapOverride item);
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(LoadBalancerListenerBootstrapOverride item);
    public A addToBrokers(int index,LoadBalancerListenerBrokerOverride item);
    public A setToBrokers(int index,LoadBalancerListenerBrokerOverride item);
    public A addToBrokers(LoadBalancerListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<LoadBalancerListenerBrokerOverride> items);
    public A removeFromBrokers(LoadBalancerListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<LoadBalancerListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public List<LoadBalancerListenerBrokerOverride> getBrokers();
    public List<LoadBalancerListenerBrokerOverride> buildBrokers();
    public LoadBalancerListenerBrokerOverride buildBroker(int index);
    public LoadBalancerListenerBrokerOverride buildFirstBroker();
    public LoadBalancerListenerBrokerOverride buildLastBroker();
    public LoadBalancerListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(List<LoadBalancerListenerBrokerOverride> brokers);
    public A withBrokers(LoadBalancerListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(LoadBalancerListenerBrokerOverride item);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,LoadBalancerListenerBrokerOverride item);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerListenerBootstrapOverrideFluent<LoadBalancerListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerListenerBrokerOverrideFluent<LoadBalancerListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/LoadBalancerListenerOverrideFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface LoadBalancerListenerOverrideFluent<A extends LoadBalancerListenerOverrideFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBootstrap instead.
 * @return The buildable object.
 */
@Deprecated public LoadBalancerListenerBootstrapOverride getBootstrap();
    public LoadBalancerListenerBootstrapOverride buildBootstrap();
    public A withBootstrap(LoadBalancerListenerBootstrapOverride bootstrap);
    public Boolean hasBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> withNewBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> withNewBootstrapLike(LoadBalancerListenerBootstrapOverride item);
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrap();
    public LoadBalancerListenerOverrideFluent.BootstrapNested<A> editOrNewBootstrapLike(LoadBalancerListenerBootstrapOverride item);
    public A addToBrokers(int index,LoadBalancerListenerBrokerOverride item);
    public A setToBrokers(int index,LoadBalancerListenerBrokerOverride item);
    public A addToBrokers(LoadBalancerListenerBrokerOverride... items);
    public A addAllToBrokers(Collection<LoadBalancerListenerBrokerOverride> items);
    public A removeFromBrokers(LoadBalancerListenerBrokerOverride... items);
    public A removeAllFromBrokers(Collection<LoadBalancerListenerBrokerOverride> items);
    public A removeMatchingFromBrokers(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildBrokers instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<LoadBalancerListenerBrokerOverride> getBrokers();
    public java.util.List<LoadBalancerListenerBrokerOverride> buildBrokers();
    public LoadBalancerListenerBrokerOverride buildBroker(int index);
    public LoadBalancerListenerBrokerOverride buildFirstBroker();
    public LoadBalancerListenerBrokerOverride buildLastBroker();
    public LoadBalancerListenerBrokerOverride buildMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    public Boolean hasMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);
    public A withBrokers(java.util.List<LoadBalancerListenerBrokerOverride> brokers);
    public A withBrokers(LoadBalancerListenerBrokerOverride... brokers);
    public Boolean hasBrokers();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> addNewBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> addNewBrokerLike(LoadBalancerListenerBrokerOverride item);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> setNewBrokerLike(int index,LoadBalancerListenerBrokerOverride item);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editBroker(int index);
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editFirstBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editLastBroker();
    public LoadBalancerListenerOverrideFluent.BrokersNested<A> editMatchingBroker(io.fabric8.kubernetes.api.builder.Predicate<LoadBalancerListenerBrokerOverrideBuilder> predicate);

    public interface BootstrapNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerListenerBootstrapOverrideFluent<LoadBalancerListenerOverrideFluent.BootstrapNested<N>>{

        
    public N and();    public N endBootstrap();
}
    public interface BrokersNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LoadBalancerListenerBrokerOverrideFluent<LoadBalancerListenerOverrideFluent.BrokersNested<N>>{

        
    public N and();    public N endBroker();
}


}
